Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitCustomGenerator ¶
func InitCustomGenerator(cusGen Generator)
InitCustomGenerator if you give a custom generator, it will be used to generate id and not check worker number format anymore
func IsCustomGenerator ¶
func IsCustomGenerator() bool
IsCustomGenerator returns whether the custom generator is initialized.
Types ¶
Click to show internal directories.
Click to hide internal directories.